from setuptools import setup, find_packages

setup(
    name="my_hellohaj",
    version="0.1.0",
    packages=find_packages(),
    install_requires=[],  
    entry_points={
        "console_scripts": [
            "myhello = aa.cli:main", 
        ],
    },
    author="Your Name",
    description="A simple hello world program that can be installed via pip",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/my_hello",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
